summaryrefslogtreecommitdiff
path: root/module.nix
diff options
context:
space:
mode:
Diffstat (limited to 'module.nix')
-rw-r--r--module.nix52
1 files changed, 28 insertions, 24 deletions
diff --git a/module.nix b/module.nix
index 56ca58d..096cacc 100644
--- a/module.nix
+++ b/module.nix
@@ -72,7 +72,7 @@ inputs:
config.specs.nix = {
lazy = true;
data = null;
- extraPackages = with pkgs; [
+ runtimePkgs = with pkgs; [
nixd
nixfmt
];
@@ -83,7 +83,7 @@ inputs:
data = with pkgs.vimPlugins; [
lazydev-nvim
];
- extraPackages = with pkgs; [
+ runtimePkgs = with pkgs; [
lua-language-server
stylua
];
@@ -92,31 +92,28 @@ inputs:
lazy = true;
enable = false;
data = null;
- extraPackages = with pkgs; [
+ runtimePkgs = with pkgs; [
bash-language-server
];
};
config.specs.C = {
lazy = true;
data = null;
- extraPackages = with pkgs; [
- clang-tools
- ];
+ runtimePkgs = with pkgs; [ ];
};
config.specs.rust = {
# enable = false;
lazy = true;
- data = null;
- extraPackages = with pkgs; [
- rust-analyzer
- rustfmt
+ data = with pkgs.vimPlugins; [
+ rustaceanvim
];
+ runtimePkgs = with pkgs; [ ];
};
config.specs.zig = {
enable = false;
lazy = true;
data = null;
- extraPackages = with pkgs; [
+ runtimePkgs = with pkgs; [
zls
];
};
@@ -126,7 +123,7 @@ inputs:
# If we provided any from within either spec, anyway
after = [ "lze" ];
# note we didn't have to specify the `lze` specs name, because it was a top level spec
- extraPackages = with pkgs; [
+ runtimePkgs = with pkgs; [
tree-sitter
];
# this `lazy = true` definition will transfer to specs in the contained DAL, if there is one.
@@ -137,26 +134,33 @@ inputs:
# here we chose a DAL of plugins, but we can also pass a single plugin, or null
# plugins are of type wlib.types.stringable
data = with pkgs.vimPlugins; [
- vim-sleuth
+ {
+ data = vim-sleuth;
+ lazy = false;
+ }
+ {
+ data = nvim-web-devicons;
+ lazy = false;
+ }
+
config.nvim-lib.neovimPlugins.base46
+ config.nvim-lib.neovimPlugins.neogit
+ codediff-nvim
nvim-lspconfig
oil-nvim
vim-startuptime
blink-cmp
+ nvim-surround
colorful-menu-nvim
luasnip
+ fff-nvim
lualine-nvim
nvim-lint
conform-nvim
+ gitsigns-nvim
nvim-treesitter-textobjects
- mini-pick
- mini-diff
- mini-surround
- mini-indentscope
nvim-ts-autotag
- vim-fugitive
- vim-rhubarb
- diffview-nvim
+ hlchunk-nvim
(nvim-treesitter.withPlugins (
plugins: with plugins; [
nix
@@ -196,16 +200,16 @@ inputs:
# config.runtimeDeps = lib.mkDefault (parentSpec.runtimeDeps or false);
# config.pluginDeps = lib.mkDefault (parentSpec.pluginDeps or false);
# or something more interesting like:
- # add an extraPackages field to the specs themselves
- options.extraPackages = lib.mkOption {
+ # add an runtimePkgs field to the specs themselves
+ options.runtimePkgs = lib.mkOption {
type = lib.types.listOf wlib.types.stringable;
default = [ ];
- description = "a extraPackages spec field to put packages to suffix to the PATH";
+ description = "a runtimePkgs spec field to put packages to suffix to the PATH";
};
# You could do this too
# config.before = lib.mkDefault [ "INIT_MAIN" ];
};
- config.extraPackages = config.specCollect (acc: v: acc ++ (v.extraPackages or [ ])) [ ];
+ config.runtimePkgs = config.specCollect (acc: v: acc ++ (v.runtimePkgs or [ ])) [ ];
# Inform our lua of which top level specs are enabled
options.settings.cats = lib.mkOption {